@@ -10,8 +10,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
-
 from os_vif import exception
 from os_vif.tests.unit import base
 
@@ -24,10 +22,10 @@ class VIFExceptionTestCase(base.TestCase):
             msg_fmt = "default message"
 
         exc = FakeVIFException()
-        self.assertEqual(six.text_type(exc), 'default message')
+        self.assertEqual(str(exc), 'default message')
 
     def test_error_msg(self):
-        self.assertEqual(six.text_type(exception.ExceptionBase('test')),
+        self.assertEqual(str(exception.ExceptionBase('test')),
                          'test')
 
     def test_default_error_msg_with_kwargs(self):
@@ -35,4 +33,4 @@ class VIFExceptionTestCase(base.TestCase):
             msg_fmt = "default message: %(foo)s"
 
         exc = FakeVIFException(foo="bar")
-        self.assertEqual(six.text_type(exc), 'default message: bar')
+        self.assertEqual(str(exc), 'default message: bar')
