@@ -34,6 +34,10 @@ from vif_plug_ovs.ovsdb import ovsdb_lib
 LOG = logging.getLogger(__name__)
 
 
+def is_trunk_bridge(bridge_name):
+    return bridge_name.startswith(constants.TRUNK_BR_PREFIX)
+
+
 class OvsPlugin(plugin.PluginBase):
     """An OVS plugin that can setup VIFs in many ways
 
@@ -202,8 +206,12 @@ class OvsPlugin(plugin.PluginBase):
         # bound the interface in the vif binding details so isolation
         # can be enabled automatically in the future.
         bridge = kwargs.pop('bridge', vif.network.bridge)
-        if self._isolate_vif(vif_name, bridge):
+        # See bug #2069543.
+        if (self._isolate_vif(vif_name, bridge) and
+                not is_trunk_bridge(bridge)):
             kwargs['tag'] = constants.DEAD_VLAN
+            kwargs['vlan_mode'] = 'trunk'
+            kwargs['trunks'] = constants.DEAD_VLAN
         qos_type = self._get_qos_type(vif)
         if qos_type is not None:
             # NOTE(sean-k-mooney): If the port is not already created
@@ -303,8 +311,8 @@ class OvsPlugin(plugin.PluginBase):
         instance_id = instance_info.uuid
         LOG.debug(
             'creating patch port pair \n'
-            f'{port_bridge_name}:({port_bridge_patch}) -> '
-            f'{int_bridge_name}:({int_bridge_patch})'
+            f'{port_bridge_name}: ({port_bridge_patch}) -> '
+            f'{int_bridge_name}: ({int_bridge_patch})'
         )
         self.ovsdb.create_patch_port_pair(
             port_bridge_name, port_bridge_patch, int_bridge_name,
@@ -384,11 +392,8 @@ class OvsPlugin(plugin.PluginBase):
                 vif=vif,
                 err="This vif type is not supported by this plugin")
 
-    def _is_trunk_bridge(self, bridge_name):
-        return bridge_name.startswith(constants.TRUNK_BR_PREFIX)
-
     def _delete_bridge_if_trunk(self, vif):
-        if self._is_trunk_bridge(vif.network.bridge):
+        if is_trunk_bridge(vif.network.bridge):
             self.ovsdb.delete_ovs_bridge(vif.network.bridge)
 
     def _unplug_vhostuser(self, vif, instance_info):
